==> react-ui-component-0.0.91.tgz: package/main/entre.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import resetCss from '../component/css/reset.less';
const carousel_css = require('../component/css/carousel.less');
const popup_css = require('../component/css/popup.less');
const draggable_css = require('../component/css/draggable.less');
const dropdown_css = require('../component/css/dropdown.less');
const menu_css = require("../component/css/menu.less");
const modal_css = require('../component/css/modal.less');
const pin_css = require('../component/css/pin.less');
const tab_css = require('../component/css/tab.less');

import CheckBoxDemo from "./demo/CheckBoxDemo.jsx";
import RadioDemo from "./demo/RadioDemo.jsx";
import RadioGroupDemo from "./demo/RadioGroupDemo.jsx";
import CheckBoxGroupDemo from "./demo/CheckBoxGroupDemo.jsx";
import DropDownDemo from "./demo/DropDownDemo.jsx";
import MenuDemo from "./demo/MenuDemo.jsx";
import ConfirmBoxDemo from "./demo/ConfirmBoxDemo.jsx";
import TooltipDemo from "./demo/TooltipDemo.jsx";
import ModalDemo from "./demo/ModalDemo.jsx";
import TabDemo from "./demo/TabDemo.jsx";
import PinDemo from "./demo/PinDemo.jsx";
import DraggableDemo from "./demo/DraggableDemo.jsx";
import CarouselDemo from "./demo/CarouselDemo.jsx";

ReactDOM.render(<CheckBoxDemo/>, document.getElementById('checkbox'));
ReactDOM.render(<RadioDemo/>, document.getElementById('radio'));
ReactDOM.render(<RadioGroupDemo/>, document.getElementById('radio-group'));
ReactDOM.render(<CheckBoxGroupDemo/>, document.getElementById('checkbox-group'));
ReactDOM.render(<DropDownDemo/>, document.getElementById('drop-down'));
ReactDOM.render(<MenuDemo/>, document.getElementById('menu'));
ReactDOM.render(<ConfirmBoxDemo/>, document.getElementById('confirm-box'));
ReactDOM.render(<TooltipDemo/>, document.getElementById('tooltip'));
ReactDOM.render(<ModalDemo/>, document.getElementById('modal'));
ReactDOM.render(<TabDemo/>, document.getElementById('tab'));
ReactDOM.render(<PinDemo/>, document.getElementById('pin'));
ReactDOM.render(<DraggableDemo/>, document.getElementById('draggable'));
ReactDOM.render(<CarouselDemo/>, document.getElementById('carousel'));

==> react-ui-component-0.0.95.tgz: package/main/entre.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import resetCss from './css/reset.less';
const carousel_css = require('./css/carousel.less');
const popup_css = require('./css/popup.less');
const draggable_css = require('./css/draggable.less');
const dropdown_css = require('./css/dropdown.less');
const menu_css = require("./css/menu.less");
const modal_css = require('./css/modal.less');
const pin_css = require('./css/pin.less');
const tab_css = require('./css/tab.less');
const pagination_css = require('./css/pagination.less');

import CheckBoxDemo from "./demo/CheckBoxDemo.jsx";
import RadioDemo from "./demo/RadioDemo.jsx";
import RadioGroupDemo from "./demo/RadioGroupDemo.jsx";
import CheckBoxGroupDemo from "./demo/CheckBoxGroupDemo.jsx";
import DropDownDemo from "./demo/DropDownDemo.jsx";
import MenuDemo from "./demo/MenuDemo.jsx";
import ConfirmBoxDemo from "./demo/ConfirmBoxDemo.jsx";
import TooltipDemo from "./demo/TooltipDemo.jsx";
import ModalDemo from "./demo/ModalDemo.jsx";
import TabDemo from "./demo/TabDemo.jsx";
import PinDemo from "./demo/PinDemo.jsx";
import DraggableDemo from "./demo/DraggableDemo.jsx";
import CarouselDemo from "./demo/CarouselDemo.jsx";
import PaginationDemo from "./demo/PaginationDemo.jsx";

ReactDOM.render(<CheckBoxDemo/>, document.getElementById('checkbox'));
ReactDOM.render(<RadioDemo/>, document.getElementById('radio'));
ReactDOM.render(<RadioGroupDemo/>, document.getElementById('radio-group'));
ReactDOM.render(<CheckBoxGroupDemo/>, document.getElementById('checkbox-group'));
ReactDOM.render(<DropDownDemo/>, document.getElementById('drop-down'));
ReactDOM.render(<MenuDemo/>, document.getElementById('menu'));
ReactDOM.render(<ConfirmBoxDemo/>, document.getElementById('confirm-box'));
ReactDOM.render(<TooltipDemo/>, document.getElementById('tooltip'));
ReactDOM.render(<ModalDemo/>, document.getElementById('modal'));
ReactDOM.render(<TabDemo/>, document.getElementById('tab'));
ReactDOM.render(<PinDemo/>, document.getElementById('pin'));
ReactDOM.render(<DraggableDemo/>, document.getElementById('draggable'));
ReactDOM.render(<CarouselDemo/>, document.getElementById('carousel'));
ReactDOM.render(<PaginationDemo/>, document.getElementById('pagination'));
